#
# spec file for package mathgl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with zypper_posttrans
%define octave_args --no-window-system --norc
%define libname libmgl

# At least python 3.8 is required; Leap <= 15.3 only has python 3.6
%if 0%{?suse_version} >= 1550
%bcond_without python
%else
%bcond_with python
%endif
%define skip_python2 1

%define libversion 8

# oct_version must be x.y.z
%define oct_version %{version}
# Octave is too recent for oS >= 1699, and swig is too old for Leap 15.x
%bcond_with    octave

# Drop doc package as it is a constant source of build pain
%bcond_with docs

%if 0%{?fedora_version}
%define _defaultdocdir %{_docdir}
%endif
Name:           mathgl
Version:        8.0.1
Release:        9.8
Summary:        Library for making scientific graphics
License:        GPL-3.0-only
URL:            http://mathgl.sourceforge.net
Source0:        http://downloads.sourceforge.net/mathgl/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM mathgl-fix-python-module-path.patch -- Make python modules install arch-depended
Patch1:         mathgl-fix-python-module-path.patch
# PATCH-FEATURE-UPSTREAM mathgl-examples-install.patch -- Enable examples install
Patch2:         mathgl-examples-install.patch
# PATCH-FIX-OPENSUSE mathgl-doc-path.patch -- Locate documentation to right place
Patch3:         mathgl-doc-path.patch
# PATCH-FIX-OPENSUSE udav-help-path.patch -- fix path to documentation directory
Patch4:         udav-help-path.patch
# PATCH-FIX-OPENSUSE mathgl-texmf-dir.patch -- set correct path to texmf directory
Patch5:         mathgl-texmf-dir.patch
# PATCH-FIX-OPENSUSE mathgl-no-default-qt.patch -- do not set a default qt
Patch7:         mathgl-no-default-qt.patch
# PATCH-FIX-UPSTREAM mathgl-libharu2_4-compat.patch badshah400@gmail.com -- Fix compilation against libharu 2.4.x [https://sourceforge.net/p/mathgl/bugs/48/]
Patch8:         mathgl-libharu2_4-compat.patch
BuildRequires:  cmake >= 2.8.12
BuildRequires:  desktop-file-utils
BuildRequires:  fltk-devel
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  giflib-devel
BuildRequires:  gsl-devel
BuildRequires:  hdf5-devel
BuildRequires:  libharu-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libtiff-devel
BuildRequires:  libtool
BuildRequires:  lua51-devel
BuildRequires:  openmpi-macros-devel
BuildRequires:  swig
BuildRequires:  sz2-devel
BuildRequires:  texlive-filesystem
BuildRequires:  wxGTK3-devel
%if %{with python}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy-devel < 2.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
Requires:       python-numpy < 2.0
%endif
%if %{with octave}
BuildRequires:  octave-devel
BuildRequires:  swig >= 4.0
%endif
%if 0%{?fedora_version}
BuildRequires:  fltk-fluid
BuildRequires:  libXmu-devel
%endif
%if %{with docs}
%if 0%{?fedora_version}
BuildRequires:  texi2html
BuildRequires:  texinfo-tex
%else
BuildRequires:  texinfo
BuildRequires:  texlive-latex
%endif
%endif
%python_subpackages

%description
MathGL is a library for making scientific graphics. It provides data
plotting and handling of large data arrays, as well as window and
console modes and for embedding into other programs. MathGL
integrates into FLTK, Qt and OpenGL applications.

%package -n     %{libname}%{libversion}
Summary:        Library for making scientific graphics
Requires:       %{name}-fonts >= %{version}
Provides:       %{name} = %{version}

%description -n %{libname}%{libversion}
MathGL is a library for making scientific graphics. It provides data
plotting and handling of large data arrays, as well as window and
console modes and for embedding into other programs.

%package -n     %{libname}-mpi%{libversion}
Summary:        MathGL library with MPI support
%openmpi_requires

%description -n %{libname}-mpi%{libversion}
MathGL is a library for making scientific graphics. It provides data
plotting and handling of large data arrays, as well as window and
console modes and for embedding into other programs.

%package -n     %{libname}-fltk%{libversion}
Summary:        MathGL FLTK widget library

%description -n %{libname}-fltk%{libversion}
MathGL is a library for making scientific graphics. It provides data
plotting and handling of large data arrays, as well as window and
console modes and for embedding into other programs.

%package -n     %{libname}-glut%{libversion}
Summary:        MathGL window library

%description -n %{libname}-glut%{libversion}
MathGL is a library for making scientific graphics. It provides data
plotting and handling of large data arrays, as well as window and
console modes and for embedding into other programs.

%package -n     %{libname}-qt5-%{libversion}
Summary:        MathGL Qt5 widget library

%description -n %{libname}-qt5-%{libversion}
MathGL is a library for making scientific graphics. It provides data
plotting and handling of large data arrays, as well as window and
console modes and for embedding into other programs.

%package -n     %{libname}-wnd%{libversion}
Summary:        MathGL window library

%description -n %{libname}-wnd%{libversion}
MathGL is a library for making scientific graphics. It provides data
plotting and handling of large data arrays, as well as window and
console modes and for embedding into other programs.

%package -n     %{libname}-wx%{libversion}
Summary:        MathGL wxWidgets library

%description -n %{libname}-wx%{libversion}
MathGL is a library for making scientific graphics. It provides data
plotting and handling of large data arrays, as well as window and
console modes and for embedding into other programs.

%package        cgi
Summary:        MathGL CGI binary

%description    cgi
This package contains the MathGL binary for parsing CGI scripts.

%package        devel
Summary:        Libraries and header files for the MathGL library
Requires:       %{libname}%{libversion} = %{version}
Requires:       %{libname}-fltk%{libversion} = %{version}
Requires:       %{libname}-glut%{libversion} = %{version}
Requires:       %{libname}-mpi%{libversion} = %{version}
Requires:       %{libname}-qt5-%{libversion} = %{version}
Requires:       %{libname}-wnd%{libversion} = %{version}
Requires:       %{libname}-wx%{libversion} = %{version}
Requires:       cmake
%if 0%{?suse_version}
%if %{with docs}
Recommends:     %{name}-doc
%endif
%endif

%description    devel
MathGL is a library for making scientific graphics. It provides data
plotting and handling of large data arrays, as well as window and
console modes and for embedding into other programs.

This package contains libraries and header files for developing
applications that use MathGL.

%package        devel-static
Summary:        Static libraries for MathGL
Requires:       mathgl-devel = %{version}

%description    devel-static
MathGL is a library for making scientific graphics. It provides data
plotting and handling of large data arrays, as well as window and
console modes and for embedding into other programs.

This package contains static libraries for developing applications
that use MathGL.

%package        doc
Summary:        Documentation for MathGL
BuildArch:      noarch

%description    doc
MathGL is a library for making scientific graphics. It provides data
plotting and handling of large data arrays, as well as window and
console modes and for embedding into other programs.

This package provides the documentation for MathGL in HTML format.

%package        doc-pdf
Summary:        Documentation for MathGL
BuildArch:      noarch

%description    doc-pdf
MathGL is a library for making scientific graphics. It provides data
plotting and handling of large data arrays, as well as window and
console modes and for embedding into other programs.

This package provides the documentation for MathGL in PDF format.

%package        doc-ru
Summary:        Russian documentation for MathGL
Requires:       mathgl-doc = %{version}
Provides:       locale(mathgl-doc:ru)
BuildArch:      noarch

%description    doc-ru
MathGL is a library for making scientific graphics. It provides data
plotting and handling of large data arrays, as well as window and
console modes and for embedding into other programs.

This package provides Russian documentation for MathGL.

%package        examples
Summary:        Examples for %{name} library

%description    examples
MathGL is a library for making scientific graphics. It provides data
plotting and handling of large data arrays, as well as window and
console modes and for embedding into other programs.

This package contains examples of using MathGL.

%package        fonts
Summary:        Fonts for the MathGL library
BuildArch:      noarch

%description    fonts
This package contains command fonts for MathGL library.

%package        lua
Summary:        Lua interface for the MathGL library

%description    lua
MathGL is a library for making scientific graphics. It provides data
plotting and handling of large data arrays, as well as window and
console modes and for embedding into other programs.

This package provides lua interface for MathGL.

%package -n     octave-mathgl
Summary:        Octave interface for the MathGL library
Requires:       octave-cli

%description -n octave-mathgl
MathGL is a library for making scientific graphics. It provides data
plotting and handling of large data arrays, as well as window and
console modes and for embedding into other programs.

This package provides Octave interface for MathGL.

%package        tex
Summary:        MathGL scripts for LaTeX documents
Requires:       mathgl-tools >= %{version}
Requires(post): coreutils
Requires(posttrans): texlive
Requires(postun): coreutils
Requires(postun): texlive
Requires(pre):  texlive
Recommends:     mathgl-tex-doc = %{version}
Provides:       tex(mgltex.sty)
BuildArch:      noarch

%description    tex
MathGL is a library for making scientific graphics. It provides data
plotting and handling of large data arrays, as well as window and
console modes and for embedding into other programs.

This package allows to use MathGL scripts in LaTeX documents.

%package        tex-doc
Summary:        Documentation for mglTeX
Conflicts:      texlive-mgltex-doc
BuildArch:      noarch

%description    tex-doc
MathGL is a library for making scientific graphics. It provides data
plotting and handling of large data arrays, as well as window and
console modes and for embedding into other programs.

This package provides documentation for mglTeX.

%package        tools
Summary:        Command line tools for the MathGL library

%description    tools
This package contains command line tools for making scientific graphics.

%package -n     udav
Summary:        Data handling and plotting tool

%description -n udav
UDAV is a program for data array visualization using the MathGL
library. It support a wide spectrum of graphics, a simple script
language and visual data handling and editing. It has a window
interface for data viewing, changing and plotting. It can also
execute MGL scripts, set up, rotate graphics, and so on.

%lang_package

%prep
%setup -q
%autopatch -p1

# Link mgl-mpi to mgl
sed -i 's/target_link_libraries(mgl-mpi /\0 mgl /' src/CMakeLists.txt

# Correct octave-mathgl version
sed -i 's/2.0/%{oct_version}/' lang/DESCRIPTION

# convert EOL encodings, maintaining timestamps
sed -i 's/\r$//' AUTHORS README

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
%setup_openmpi

%{python_expand # For all supported python flavors
export PYTHON=$python
echo "Building for $python_ providing %{$python_provides} "
%define __builddir ${PYTHON}_build
pushd .
%cmake \
      -DCMAKE_INSTALL_PREFIX:PATH=%{_prefix}  \
      -DMathGL_INSTALL_LIB_DIR:PATH=%{_lib}   \
      -DMathGL_INSTALL_CMAKE_DIR:PATH=%{_libdir}/cmake/mathgl   \
      -DTEXMFDIR:PATH=%{_datadir}/texmf/      \
      -DCMAKE_C_FLAGS="%{optflags}"	      \
      -DCMAKE_CXX_FLAGS="%{optflags}"	      \
      -Denable-double=on                      \
      -Denable-mpi=on                         \
      -Denable-pthread=off                    \
      -Denable-openmp=on                      \
      -Denable-ltdl=on                        \
      -Denable-gsl=on                         \
      -Denable-jpeg=on                        \
      -Denable-png=on                         \
      -Denable-zlib=on                        \
      -Denable-pdf=on                         \
      -Denable-gif=on                         \
      -Denable-hdf5=on                        \
      -Denable-opengl=on                      \
      -Denable-python=%{?with_python:on}%{!?with_python:off} \
      -DPY3VERSION_DOTTED=%{$python_version}  \
      -Denable-json-sample=off                \
%if "%{$python_provides}" == "python3" || "$python_" == "python3_"
      -Denable-doc-html=%{?with_docs:on}%{!?with_docs:off} \
      -Denable-doc-pdf-en=%{?with_docs:on}%{!?with_docs:off} \
      -Denable-fltk=on                        \
      -Denable-glut=on                        \
      -Denable-lua=on                         \
      -Denable-mgltex=on                      \
      -Denable-octave=%{?with_octave:on}%{!?with_octave:off} \
      -Denable-octave-install=OFF             \
      -Denable-qt=on                          \
      -Denable-wx=on                          \
%else
      -Denable-doc-html=off                   \
      -Denable-doc-pdf-en=off                 \
      -Denable-fltk=off                       \
      -Denable-glut=off                       \
      -Denable-lua=off                        \
      -Denable-mgltex=off                     \
      -Denable-octave=off                     \
      -Denable-octave-install=off             \
      -Denable-qt5=off                        \
      -Denable-wx=off                         \
%endif
      %{nil}

%cmake_build
popd
}

%install
%{python_expand # For all supported python flavors
export PYTHON=$python
%define __builddir ${PYTHON}_build
%cmake_install

%if "%{$python_provides}" == "python3" || "$python_" == "python3_"
pushd %{__builddir}

%if %{with octave}
# Can not use enable-octave-install, as it ignores the buildroot
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:%{buildroot}%{_libdir}
# Install octave-mathgl
mkdir -p %{buildroot}%{_libdir}/octave/packages
mkdir -p %{buildroot}%{_datadir}/octave/packages
octave %{octave_args} --eval \
  "pkg prefix %{buildroot}%{_datadir}/octave/packages %{buildroot}%{_libdir}/octave/packages; pkg install lang/%{name}.tar.gz"
# rm %%{buildroot}%%{_datadir}/octave/packages/*/packinfo/.autoload
# remove octave module archive
rm %{buildroot}%{_datadir}/%{name}/%{name}.tar.gz
%endif

# move mgl.cgi
install -d %{buildroot}/srv/www/cgi-bin/
mv %{buildroot}%{_prefix}/lib/cgi-bin/mgl.cgi %{buildroot}/srv/www/cgi-bin/mgl.cgi

# LaTeX package (based on TeXLive spec files)
%if %{with zypper_posttrans}
mkdir -p %{buildroot}%{_localstatedir}/adm/update-scripts
ln -sf %{_datadir}/texmf/texconfig/zypper.py \
    %{buildroot}%{_localstatedir}/adm/update-scripts/texlive-mgltex-%{version}-%{release}-zypper
%endif

%find_lang %{name}
# Copy mathgl.lang file to main dir for use with file list
cp %{name}.lang ../

popd
%endif
}

%if %{with docs}
# R-B diagnostics
# fexport.prc is nontrivial to fix, as it contains a time based UUID
# fexport.pdf is non-reproducible due to embedded fexport.prc
grep `date +'%Y'` %{buildroot}%{_docdir}/mathgl/png/fexport*.{eps,svg}
sha256sum %{buildroot}%{_docdir}/mathgl/png/fexport*.{prc,pdf,eps,svg}
%endif

# %%post doc
# %%install_info --info-dir=%%{_infodir} %%{_infodir}/%%{name}_en.info.gz
# %%install_info --info-dir=%%{_infodir} %%{_infodir}/%%{name}_en.info-1.gz
# %%install_info --info-dir=%%{_infodir} %%{_infodir}/%%{name}_en.info-2.gz
#
# %%postun doc
# %%install_info_delete --info-dir=%%_infodir %%{_infodir}/%%{name}_en.info.gz
# %%install_info_delete --info-dir=%%_infodir %%{_infodir}/%%{name}_en.info-1.gz
# %%install_info_delete --info-dir=%%_infodir %%{_infodir}/%%{name}_en.info-2.gz

%post -n %{libname}%{libversion} -p /sbin/ldconfig
%postun -n %{libname}%{libversion} -p /sbin/ldconfig
%post -n %{libname}-mpi%{libversion} -p /sbin/ldconfig
%postun -n %{libname}-mpi%{libversion} -p /sbin/ldconfig
%post -n %{libname}-fltk%{libversion} -p /sbin/ldconfig
%postun -n %{libname}-fltk%{libversion} -p /sbin/ldconfig
%post -n %{libname}-glut%{libversion} -p /sbin/ldconfig
%postun -n %{libname}-glut%{libversion} -p /sbin/ldconfig
%post -n %{libname}-qt5-%{libversion} -p /sbin/ldconfig
%postun -n %{libname}-qt5-%{libversion} -p /sbin/ldconfig
%post -n %{libname}-wnd%{libversion} -p /sbin/ldconfig
%postun -n %{libname}-wnd%{libversion} -p /sbin/ldconfig
%post -n %{libname}-wx%{libversion} -p /sbin/ldconfig
%postun -n %{libname}-wx%{libversion} -p /sbin/ldconfig

%if %{with octave}
%post -n octave-mathgl
octave -qf %{octave_args} --eval "pkg rebuild -auto mathgl"

%postun -n octave-mathgl
octave -qf %{octave_args} --eval "pkg rebuild"
%endif

%post tex
mkdir -p %{_localstatedir}/run/texlive
> %{_localstatedir}/run/texlive/run-mktexlsr
> %{_localstatedir}/run/texlive/run-update

%postun tex
if test $1 = 0; then
    %{_bindir}/mktexlsr 2> /dev/null || :
    exit 0
fi
mkdir -p %{_localstatedir}/run/texlive
> %{_localstatedir}/run/texlive/run-mktexlsr
> %{_localstatedir}/run/texlive/run-update

%posttrans tex
test -f %{_localstatedir}/run/texlive/run-update || exit 0
test -z "$ZYPP_IS_RUNNING" || exit 0
VERBOSE=false %{_datadir}/texmf/texconfig/update || :
rm -f %{_localstatedir}/run/texlive/run-update

%files -n %{libname}%{libversion}
%{_libdir}/libmgl.so.%{libversion}*

%files -n %{libname}-mpi%{libversion}
%{_libdir}/libmgl-mpi.so.%{libversion}*

%files -n %{libname}-fltk%{libversion}
%{_libdir}/libmgl-fltk.so.%{libversion}*

%files -n %{libname}-glut%{libversion}
%{_libdir}/libmgl-glut.so.%{libversion}*

%files -n %{libname}-qt5-%{libversion}
%{_libdir}/libmgl-qt5.so.%{libversion}*

%files -n %{libname}-wnd%{libversion}
%{_libdir}/libmgl-wnd.so.%{libversion}*

%files -n %{libname}-wx%{libversion}
%{_libdir}/libmgl-wx.so.%{libversion}*

%files -n %{name}-cgi
%dir /srv/www
%dir /srv/www/cgi-bin
/srv/www/cgi-bin/mgl.cgi
%if %{with docs}
%{_mandir}/man1/mgl.cgi.1%{?ext_man}
%endif

%files -n %{name}-devel
%license COPYING
%doc AUTHORS ChangeLog.txt README
%{_includedir}/mgl2/
%{_libdir}/libmgl*.so
%dir %{_libdir}/cmake/mathgl
%dir %{_libdir}/cmake/mathgl2
%{_libdir}/cmake/mathgl/*.cmake
%{_libdir}/cmake/mathgl2/*.cmake

%files -n %{name}-lang -f %{name}.lang

%files -n %{name}-devel-static
%{_libdir}/*.a

%if %{with docs}
%files -n %{name}-doc
%dir %{_docdir}/mathgl
%doc %{_docdir}/mathgl/png/
%doc %{_docdir}/mathgl/udav/
%doc %{_docdir}/mathgl/*.html
%exclude %{_docdir}/mathgl/*.pdf
%doc %{_docdir}/mathgl/*.png
%exclude %{_docdir}/mathgl/mathgl_ru.html
%exclude %{_docdir}/mathgl/mgl_ru.html
# %%{_infodir}/%%{name}_en.info*.gz

%files -n %{name}-doc-pdf
%doc %{_docdir}/mathgl/*.pdf

%files -n %{name}-doc-ru
%doc %{_docdir}/mathgl/mathgl_ru.html
%doc %{_docdir}/mathgl/mgl_ru.html
%endif

%files -n %{name}-examples
%{_bindir}/mgl*example

%files -n %{name}-fonts
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/fonts/

%files -n %{name}-lua
%{_libdir}/mgl-lua.so

%if %{with octave}
%files -n octave-mathgl
%{_datadir}/octave/packages/%{name}-%{oct_version}/
%{_libdir}/octave/packages/%{name}-%{oct_version}/
%endif

%if %{with python}
%files %{python_files}
%{python_sitearch}/mathgl.py
%{python_sitearch}/_mathgl.so
%{python_sitearch}/__pycache__/*.pyc
%endif

%files -n %{name}-tex
%{_datadir}/texmf/tex/latex/mgltex/
%if %{with zypper_posttrans}
%{_localstatedir}/adm/update-scripts/texlive-mgltex-%{version}-%{release}-zypper
%endif

%files -n %{name}-tex-doc
%{_datadir}/texmf/doc/latex/mgltex/

%files -n %{name}-tools
%{_bindir}/mglconv
%{_bindir}/mglview
%{_bindir}/mgltask
%if %{with docs}
%{_mandir}/man1/mglconv.1%{?ext_man}
%{_mandir}/man1/mglview.1%{?ext_man}
%{_mandir}/man5/mgl.5%{?ext_man}
%endif

%files -n udav
%{_bindir}/udav
%{_datadir}/pixmaps/udav.png
%{_datadir}/applications/udav.desktop
%{_datadir}/mime/packages/mgl.xml
%{_datadir}/udav/
%if %{with docs}
%{_mandir}/man1/udav.1%{?ext_man}
%endif
# mgllab's .desktop file uses the same icon as udav's, so we have to bundle them in the same package
%{_bindir}/mgllab
%{_datadir}/applications/mgllab.desktop
#

%changelog
* Thu Oct 10 2024 Ana Guerrero <ana.guerrero@suse.com>
-  Add /srv/www directories to filelist [bsc#1231027]
* Tue Sep 24 2024 Atri Bhattacharya <badshah400@gmail.com>
- Pin to numpy < 2.0 to allow builds to succeed; mathgl is not
  numpy2 ready yet.
* Wed May  8 2024 Atri Bhattacharya <badshah400@gmail.com>
- Disable generation of docs, this has been a constant source of
  build failures and pain (and will be again when GCC14 becomes
  default).
* Tue Feb 27 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add dependency on setuptools.
* Mon Oct 23 2023 Nicolas Morey <nicolas.morey@suse.com>
- Update spec file to use openmpi-macros-devel and always use the
  default OpenMPI implementation.
* Tue May  9 2023 Atri Bhattacharya <badshah400@gmail.com>
- Also disable octave bindings for openSUSE >= 1699 (TW), as
  octave 8.x is not yet supported by mathgl.
* Tue Mar  7 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Disable octave bindings on Leap/SLE 15 due to missing SWIG 4.x.
- Use %%cmake macros as far as possible.
- Fix underlinking of libmgl-mpi, requires libmgl.
- Spec file cleanup.
* Tue Sep 20 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add mathgl-libharu2_4-compat.patch: Fix compilation against
  libharu 2.4.x [https://sourceforge.net/p/mathgl/bugs/48/].
- Build against wxWidgets >= 3.1 (wxGTK3) instead of
  wxWidgets=3.0.
* Sun Feb 20 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 8.0.1:
  * Increase accuracy at line segment skipping.
  * Changes in SOVERSION numbering.
  * Minor spelling fix.
- Changes from version 8.0:
  * Change version numbering according Debian rules.
  * Add accurate line segment and quadrangle/triangle face cutting
    at axis border crossing.
  * Add 'fastcut' for disable accurate but slow line/trig/quad
    primitives cutting at axis borders.
  * Restore back transparent background by default. You can set
    non-transparent background by using 'clf' or 'background'
    functions.
  * Compatibility changes for Qt5.15 and MSVC.
  * Change colorbar C-functions by adding last argument for
    options.
  * Add alpha-value in fill_background().
  * Disable Qt4 interface by default.
- Update mathgl-fix-python-module-path.patch to additionally
  correct the locations of installed python module files.
- Update shlib naming scheme in keeping with upstream so version
  changes.
- Build for multiple python versions (while ensuring stuff like
  docs, etc are only built once -- for the primary flavor).
- Add Requires: libmgl-mpi%%{libversion} dependency on -devel
  package as it is linked to.
- Required version of swig is at least 4.0 to build octave
  bindings.
- Drop %%{name}-rpmlintrc: No longer needed.
* Fri Dec 24 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.5:
  * Add functions ‘sum’, ‘prod’ at formula evaluation, like
    ‘sum(_i^2,5)’ will produce 30=0+1^2+2^2+3^2+4^2, and
    ‘prod(1+_i,5)’ will produce 120=5!. You can nest them for
    variables ‘_i’,‘_j’,...,‘_z’, like ‘sum(sum(_j+_i^2,5),5)’
    will give 200.
  * Add user-defined functions ‘fn1()’...‘fn9()’ at formula
    evaluation, like ‘fn1(3)\x^_1’ will produce x^3.
  * Add functions ‘value’, ‘spline’ at formula evaluation, like
    ‘value(a,5)’ will give value of 6-th element of a, i.e. a[5].
  * Add keep for keeping the data phase/sign or value along line i
    and j in given direction
  * Add mglODEs() (i.e. extend ode) for solving PDE, cascades and
    etc.
  * Add dcont to draw a set of curves, which are intersection of
    two isosurfaces at given level.
  * Add lines to draw a set of lines with arrows between points.
  * Add first, last to get array of first/last indexes of values
    larger specified one along given direction.
  * Add bernoulli, binomial, brownian, discrete, exponential,
    gaussian, shuffle, uniform, uniformint for data filling by
    random numbers with different distributions.
  * Add readbin to read data from binary files.
  * Add texparse to enable/disable TeX-like command parsing at
    text output.
  * Update ode: regularization is used if dt*tmax<0 (total time
    may differ, but number of steps still the same).
  * Add mgl_default_graph() – the global (default) pointer to HMGL
    for keeping plot settings, simplifying external scripts and
    capture it in GUI.
  * Add style ‘p’ in command smooth to use parabolic smoothing of
    arbitrary points.
  * Allow background for scaling image, centering image and
    tessellate image as mosaic.
  * Allow filling background by the specified color.
  * Allow masks for candle, area, region, bars, barh, chart, tape,
    face, polygon, ellipse, rhomb.
  * Allow single value specification for contour level in cont,
    contd, contp, contv, cont3, dcont, tricont.
  * Add mgl_dual_save_hdf(), mgl_real_save_hdf(),
    mgl_int_save_hdf() for saving single number in HDF5 file.
  * Add mgl_formula_calc(), mgl_formula_calc_c() for evaluating
    textual formulas of arbitrary set of data arrays.
  * Add mglDataList – global mglDataA* collection for
    viewing/changing in GUI data from external languages (like,
    Python, ...).
  * Add Armadillo interface for mglData and mglDataC.
  * If nsub parameter of command hist is negative (nsub<0) then
    the linear interpolation is used instead of spline one.
  * Add dark text colors for mgllab.
  * Minor bugfixes.
  * OBSOLETE: Qt4 interface will be disabled in the next release.
  * OBSOLETE: Functions colorbar will have extra argument opt for
    options, similarly to axis and other plotting functions. In
    C++ and SWIG-based interfaces this change "masked" by
    providing the default value for the argument.
- Minor rebase of mathgl-fix-python-module-path.patch to apply
  cleanly against updated version.
- Bump library so version appropriately.
- Enable python3 bindings: now supported by upstream; build only
  for default python3 flavour.
- Disable python bindings for Leap, since python >= 3.8 is
  required whereas Leap 15.2/3 only have python 3.6.
- Re-enable octave bindings.
- Rename python sub-package to have name consistent with
  openSUSE's python3 package naming guidelines.
- Update _constraints to require 8 GB disk space as required by
  updated version.
- Drop sed fix for location of numpy header file: no longer
  needed.
* Sun Mar 28 2021 Christophe Giboudeaux <christophe@krop.fr>
- Remove the unneeded WebKit build requirements.
  '-Denable-json-sample=off' disables the WebKit dependency.
* Mon Mar 22 2021 Atri Bhattacharya <badshah400@gmail.com>
- Disable octave bindings: no longer compatible with any
  suppported octave version.
- Disable linking to texconfig zypper posttrans configuration
  script; this script is no longer installed by texlive.
* Sun Sep  6 2020 Atri Bhattacharya <badshah400@gmail.com>
- Fix for /usr/lib -> /usr/libexec migration.
* Fri Jul 31 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add 4G min disk space default in _constraints
* Wed Jun 10 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.4.4:
  * Add minmax for positions of local maximums and minimums.
  * Add ContGen() and ContFGen() to draw contour lines manually.
    Correspondingly cont and contf commands are extended.
  * Add conts for coordinate of contour lines.
  * Extend put for partial filling if data size(s) are smaller as
    destination.
  * Classes mglFormula and mglFormulaC now can read file with
    given sizes if string have the format
    ":fname:x1:x2:y1:y2:z1:z2". Here data is supposed in range
    [x1,x2]*[y1,y2]*[z1,z2] (by default [0,1]*[0,1]*[0,1]). Calc()
    in this case return the interpolated values.
  * mglData now have operator() which work as SubData() function.
  * Minor bugfixes.
- Disable python bindings where python2 is unavailable (still no
  python3 support from upstream unfortunately).
- Drop conditionals for old, unsupported openSUSE versions.
- Enable octave bindings for openSUSE versions > 1500 (doesn't
  work with octave version in Leap 15.1, 15.2).
- Run spec-cleaner for minor specfile cleanups.
- Drop qt4 package definitions.
- Drop Group tags from packages.
* Fri Nov  1 2019 Atri Bhattacharya <badshah400@gmail.com>
- openmpi has been renamed to openmpi1 for openSUSE >= 1550;
  adapt accordingly.
* Tue Sep 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Use -ffat-lto-objects when building static libraries.
* Sat May 18 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.4.3:
  * Add 'clabel' command -- draw labels for colorbar. Should be
    used *after* drawing colorbar!
  * Extend 'ctick' command
  * Add subpixel smoothing for masks
  * Boxes around text (style '@') now use actual height and
    position of the text.
  * Add mask to EPS export. Note, mask angles are reduced to
    45*(0,1,...7) degrees for decreasing pattern size in the EPS.
  * Update default masks: '*' become dot, '^' become bricks, 'd'
    become plus, 'D' become tacks, ';' and 'j' change lengths.
  * Note, you can use brush.ods to prepare user-defined masks.
  * Add styles '^' and '_' for command 'smooth' to find
    upper/lower bound of the data.
  * Improve FlowP() to draw both branches (in positive and
    negative time direction).
  * Improve CGI interface and update website.
  * Introduce struct mdual as interface for C and C++ complex
    numbers. It is implicitly converted to std::complex<> in C++.
    And need to call c2mdual() and mdual2c() in pure C. However
    mdual is binary compatible with C _Complex numbers.
  * Add flag in CMake to manually disable support of C99 complex
    numbers.
  * Bypass user-specified extension in base font family name.
  * Improve hints in mgllab and udav.
  * Add utility 'mgltask' for making output file with a set of
    copies of mask-file. It useful for making set of initial
    conditions with a few parameters varied in specified range.
  * Add example of OpenGL output.
  * Bugfix for approximate min and max position.
  * Bugfix for position of SVG output.
  * Compatibility fixes for new versions of CMake, compilers and
    libraries.
  * INCOMPATIBLE: Formally pure C interface handle complex numbers
    by new way due to strict following of C/C++ standards.
    However, the MathGL library is binary compatible with previous
    version(s).
- Drop mathgl-fltk-includedir.patch: incorporated upstream.
- Fix Group for %%{name}-doc-pdf to Documentation/Other, as
  Documentation/PDF isn't a valid group.
* Tue May  8 2018 schwab@suse.de
- Define MathGL_INSTALL_CMAKE_DIR to correct location
* Thu Mar 29 2018 guillaume@opensuse.org
- Update to 2.4.2:
  * Add custom dialog for FLTK widgets. This can be constructed from
    C/C++ code, or from MGL script using Special commentaries.
  * Add progress for displaying the progress of execution (by ’#’
    symbols in console, or by progress-bar widget).
  * Add contp for contour lines on parametrically specified surface.
  * Add flow3 for flow threads of 3D vector field, which start from
    the plain.
  * Add variant of flow for drawing a flow thread, starting from
    specified point.
  * Add scaletext for disabling text size scaling in relative
    inplot-s (like columnplot, ...).
  * Add setup for setting all low-level flags.
  * Add coil for projecting periodical data.
  * Add modulo operation ‘%%’ (x%%y=fmod(x,y)) to the list of known
    operations in real-valued formulas.
  * Add style ‘.’ for cont to draw contour lines from saddle points.
  * Add style ‘.’ for flow to draw flow thread from saddle points.
  * Add option value in tube for setting number of edges manually.
  * Crop output of ode if NAN or INFINITY value occurs.
  * Remove style ‘~’ for plot and tens. Now, all curves try to omit
    points.
  * Add setup flag MGL_FULL_CURV which disable omitting points of curve.
  * Shift axis labels closer to axis.
  * Change size of LaTeX-like commands \sup, \sub to be the same as
    \overset, \underset.
  * Change ticks drawing in colorbar.
  * Add new section All samples of documentation with large set of
    samples for most of MathGL features.
  * Samples in documentation are generated automatically now
    (from sample.cpp).
  * INCOMPATIBLE: Make obsolete MGL command setsizescl. At this, the
    similar C/C++/Fortran/... functions still working.
  * Bugfixes.
- Rebase patch:
  * mathgl-examples-install.patch
* Tue Mar  6 2018 toddrme2178@gmail.com
- Have the -tex-doc subpackage conflict with texlive-mgltex-doc
  since they share several files
* Sat Dec  9 2017 fabian@ritter-vogt.de
- Do not build with Qt4 on TW/15 as Qt WebKit 4 is not available
  (boo#1072033)
- Explicitly disable marking either Qt version as "qt" plugin:
  * mathgl-no-default-qt.patch
* Fri Oct 27 2017 badshah400@gmail.com
- Add Provides: mathgl for the libmathgl package, to make the
  mathgl-lang package installable.
* Thu Oct 26 2017 dimstar@opensuse.org
- Adapt to latest openmpi packaging changes: setup the openmpi
  environment before calling cmake.
* Sat Aug 26 2017 jengelh@inai.de
- Trim some irrelevant words from descriptions.
* Wed Aug 16 2017 badshah400@gmail.com
- Update to version 2.4.1:
  * Add beltc plot, which is belt with manual coloring.
  * Add style '~' for plot and tens to omit some points at output.
  * Add style ':' for axis to draw lines through point (0,0,0).
  * Miscellaneous bugfixes.
- Changes from version 2.4.0:
  * Add mgllab executable, which is FLTK based version of UDAV.
  * Add string manipulation in MGL language:
  - 'str'[n] - get string of only n-th symbol;
  - 'str'+v - add value v to the last character of the string;
  - 'str',val or 'str',!val - append numeric value to the string
  * Add time value to MGL language in format:
    'hh-mm-ss_DD.MM.YYYY' or 'hh-mm-ss' or 'DD.MM.YYYY'.
  * Add iris plot to show cross-dependencies of several data
    arrays.
  * Add flame2d to draw flame fractals.
  * Add bbox to set bounding box for 2D output.
  * Add section to get part of data between specified values.
  * Add detect to found curves along data maximums.
  * Add dilate to extend the region of 1-th value.
  * Add erode to narrow the region of 1-th value.
  * Add apde to solve PDE equation in inhomogeneous nonlinear
    media with spatial dispersion.
  * Add symbol to draw the glyphs defined by addsymbol.
  * Add addsymbol to declare user-defined symbol (or glyph), which
    can be used as markers for plot (with style '&') or drawn
    itself by symbol command.
  * Add openhdf to open all data arrays from HDF file.
  * Extend crop to cut to optimal size for FFT (i.e. to closest of
    2^n*3^m*5^l).
  * Add function mgl_data_max_first() and data suffixes
    .m[xyz][fl] to find first/last maximum along direction (see
    Data information).
  * Add function mgl_datac_diff_par() to parametric derivative of
    complex data (see diff).
  * Add style 'F' for bars and barh to set fixed bar widths.
  * Add style 'a' for plot, tens, area and region to accurate
    drawing of data, which partially lie out of axis range.
  * Add style '#' for region to draw wired plot.
  * Add possibility of manual shift in multiplot.
  * Add parsing arguments of options for MGL commands.
  * MGL command correl now can perform 2d and 3d correlations.
  * Option meshnum now change the number of drawn markers for
    plot, tens, step, mark and textmark.
  * Function step handle data with x.nx>y.nx similarly to bars.
  * Extend tile and tiles by adding manual coloring and face
    orientation.
  * Add variant of MGL command copy to copy data with "incorrect"
    names.
  * Improve tick labels drawing.
  * Improve time-ticks (add weeks) and add subticks to its.
  * Improve fplot to handle several singularities.
  * Add LaTeX command \dfrac{}{}. This is full-sized version of
    \frac{}{}. Unfortunately, there is no support of nesting.
    Contrary, \frac allow nesting.
  * Add mglODEc() - ODE solver for complex variables (see ode).
  * Add cmplx(a,b)=a+i*b to the list of known functions in formula
    parsing
  * Update CMake find_package to find MathGL.
  * Increase line width for wired text.
  * Update documentation: add description of new commands, add
    hint Mixing bitmap and vector output.
  * Add translation to Russian for most of labels and messages.
  * Name all are reserved in MGL scripts now as synonym of -1.
  * INCOMPATIBLE: Replace libmgl-qt by libmgl-qt4 and libmgl-qt5
    for resolving conflicts of simultaneously installed both Qt4
    and Qt5.
  * Minor bugfixes.
- Drop mathgl-oldtexinfo.patch: fixed upstream.
- Add mathgl-fltk-includedir.patch to fix include directives for
  fltk headers.
- Split out a -lang package.
- Package the binary and desktop file for  mgllab as part of the
  - udav package; their desktop files share the same icon
  unfortunately.
- Disable doc for openSUSE <= 1320; no longer builds with old
  texi2html there.
- Move AUTHORS, ChangeLog.txt, README, COPYING to -devel package
  for all openSUSE versions; package it using %%%%doc.
- Add _constraints file to require at least 2 GB of physical
  memory on obs; otherwise builds on 64-bit openSUSE > 1320 fail.
* Sat Oct 15 2016 badshah400@gmail.com
- Update to version 2.3.5.1:
  + Library libmgl-qt is removed. You need to use libmgl-qt4 or
    libmgl-qt5 explicitly now.
  + Compatibility changes for latest MS VisualStudio.
  + Bugfixes.
- Changes from version 2.3.5:
  + See Changelog.txt for list of changes.
- Rebase mathgl-examples-install.patch for updated version.
- Define a macro for deciding whether to enable octave bindings,
  but disable octave bindings for all openSUSE versions for now
  as mathgl fails to build with updated octave. This is a
  temporary workaround, and once the build issue is fixed, we
  should revert back to enabling octave for recent openSUSE
  versions. The "enable_octave" macro is defined with this in
  mind.
- Add rpmlintrc file to suppress warning of missing man pages for
  the example binaries. These just clutter up the rpmlint log and
  have no practical use.
* Fri Aug  5 2016 tchvatal@suse.com
- Drop dependency on swig3 as swig in leap got updated to 3.x series
* Wed Feb 24 2016 dmitry_r@opensuse.org
- Update to version 2.3.4
  * Minor fixes and improvements, see included ChangeLog.txt for details
  * Update mathgl-examples-install.patch
  * Update mathgl-texmf-dir.patch
  * Drop obsolete getopt.patch
  * Drop obsolete mathgl-cmake-3.2.patch
* Tue Nov 17 2015 dmitry_r@opensuse.org
- Fix octave-mathgl package dependencies
* Wed Sep 30 2015 dmitry_r@opensuse.org
- Disable json examples
- Enable Octave module and Qt5 support for openSUSE Leap 42.1
- Use wxWidgets 3 for openSUSE Leap 42.1
* Thu Aug 13 2015 dmitry_r@opensuse.org
- Enable Octave module for openSUSE > 13.2
* Tue Jun  9 2015 schwab@suse.de
- getopt.patch: Fix use of getopt
- Compile with %%{optflags}
- Fix %%postun -n %%{libname}-wx%%{libversion}
* Sat Jun  6 2015 dmitry_r@opensuse.org
- Update to version 2.3.3
  * Minor fixes and improvements, see included ChangeLog.txt for details
  * Update mathgl-examples-install.patch
  * Update mathgl-texmf-dir.patch
- Fix build with old texinfo
  * mathgl-oldtexinfo.patch
* Sun May 31 2015 dmitry_r@opensuse.org
- Disable Octave module due to swig incompatibility with Octave 4.0
* Thu Mar 26 2015 dimstar@opensuse.org
- Add mathgl-cmake-3.2.patch: Fix build with cmake 3.2; X11 is no
  longer implicit linked.
* Sat Feb 28 2015 dmitry_r@opensuse.org
- Build with MPI support
* Tue Feb 17 2015 dmitry_r@opensuse.org
- Use texinfo for documentation generation on openSUSE > 13.2
* Mon Feb  2 2015 dmitry_r@opensuse.org
- Update to version 2.3.2
  * Update mgltex.
  * Add reading files with complex numbers by 'read' command.
  * Parallelize reading textual data files.
  * Add 'i','j','k' variables for data filling.
  * Add saving images in QMathGL even if corresponding format
    support is disabled.
  * Add cmake option MGL_DEF_FONT to change default font name
    or use built-in one (if MGL_DEF_FONT is empty).
  * Compatibility changes and bugfixes.
  * Update mathgl-fix-python-module-path.patch
- Add mathgl-tex subpackage
- Set correct path to texmf directory
  * mathgl-texmf-dir.patch
- Fix package descriptions
* Sat Jan 31 2015 dmitry_r@opensuse.org
- Update to version 2.3.1
  * Add MGL command 'load' for loading MGL commands from external
    .so module.
  * Add Logo() function to draw bitmap (logo), which is stretched
    along whole axis range
  * Add MGL command 'reset' which restore default settings and
    clear image (i.e. call DefaultPlotParam()).
  * Change y coordinate at x-z projection.
  * Improve projection of 'unrotatable' objects (like legend, title, ...).
  * Add projection (Ternary&8) which is the same as usual (Ternary&4)
    but don't print text on projections
  * Improve orientation of axis ticks and labels.
  * Add mglWnd::SetDrawFunc().
  * Add mgl_set_global_warn() and mgl_get_global_warn() for set/get
    messages of global scope.
  * Make copying private of mglGraph and derived.
  * Add virtual destructors.
  * Add some static functions for mglGraph.
  * Add option "-n" to mglconv to disable automatic saving of the image.
  * Add option "-s" to mglview and mglconv to run setup script before
    the main one.
  * Add light scaling at MGLD import.
  * Add scaling of frames at Adjust().
  * Update docs.
  * Update mathgl-examples-install.patch
* Thu Nov 13 2014 dmitry_r@opensuse.org
- Fix build on SLE12
* Wed Sep 24 2014 sfalken@opensuse.org
- Specfile Cleanup to clear some rpmlint warnings
* Thu Aug  7 2014 dmitry_r@opensuse.org
- Update to version 2.3
  * Add background image, which allow in particular semi-transparent
    background color.
  * Add primitives to draw polygon and angle arc.
  * Allow arbitrary factor for axis ticks.
  * Add function AddTick() for adding manual tick to existed ones.
  * Add new styles and symbols.
  * Add ODE solving functions for textual formulas.
  * Add function for global cubic spline interpolation, and function
    to refill using global spline.
  * Add functions "random(dat)" and "gamma_inc(a,x)" to the list
    of known functions for formula parsing
  * Add 'inf' variable to the MGL and formula parsing
  * Allow reading JPEG files for mglData::Import().
  * Warning messages and information are printed to stderr until
    call of mgl_suppress_warn(true) will disable it.
  * Add move constructor(s) if compiler support C++11 rvalues.
  * Changes in algorithms:
  - Greatly increase speed of formula parsing, and speeding up
    many other places;
  - Improve algorithm for contours drawing and filling, taking
    special attention to quasi-random data.
  - Spline() now use 5-th order polynomials to keep continuity
    of 2nd derivative too.
  - Add function attributes 'pure' or 'const', which potentially
    can speed up drawing.
  - Use spline instead of linear interpolation in functions
    Flow() and Pipe().
  - Adjust columnplot and gridplot positions for non-zero
    distance between the inplots.
  - Improve colorbar labels drawing at SetRotatedText(false)
  - Choose new scales for perspective.
  - Allow 'negative' angles for text rotation
  - Use new s-hull version for triangulation.
  * UDAV improvements.
  * Remove obsolete mathgl-fltk.patch
- Enable OpenMP support
- Move PDF documentation to separate package.
- Disable info files build due to outdated texinfo
* Wed Mar 19 2014 dmitry_r@opensuse.org
- Update to version 2.2.2.1
  * Function SetRange(v1,v2) ignore NAN values now.
  * Add enable-json-sample for building json-samples on demand only.
  * Update docs.
* Mon Mar 17 2014 dmitry_r@opensuse.org
- Fix -devel package dependences, Qt5 available only for openSUSE >= 13.2
* Mon Mar 10 2014 dmitry_r@opensuse.org
- Update to version 2.2.2
  * Add mgl_region_3d() to draw region (or ribbon) between 2 curves.
    Correspondingly extend mglGraph::Region() function and MGL
    command 'region'.
  * Allow LGPL for MathGL widgets.
  * Improve export to TeX.
  * Add missing functions to Fortran interface.
  * Bugfix for legend with enabled lighting.
  * Minor bugfixes and memory leaks.
* Fri Jan 31 2014 badshah400@gmail.com
- Re-enable octave bindings; patched swig with support for
  octave >= 3.8.0 is already in science and should fix building
  mathgl with octave enabled.
* Sun Jan 26 2014 dmitry_r@opensuse.org
- Update to version 2.2.1
  * Add Qt5 support.
  * Add Pascal interface.
  * Improve JavaScript interface.
  * Add function AddRange(char dir, mreal v1, mreal v2) and extend
    corresponding MGL commands '[xyzc]range'.
  * Add 'hypot' function for known functions in formula parsing.
  * Add style '~' to disable colorbar or axis labels. NOTE, axis
    style '_' is obsolete and should be replaced by '~'.
  * Change Aspect() if Ax=NAN. Now, Ay and Az set the ratio to
    optimal aspect (not exact value as previously).
  * Disable changes by View(),Zoom(),Perspective() for position
    of Title(), Legend(), Colorbar().
  * Partial support of perspective in CalcXYZ().
  * Speed up PDE solving.
  * Add complex versions of PDE, QO2d, QO3d.
  * Correct filled background for Box() in curved coordinates.
  * Allow nx=1 for Stem and Error.
  * Bugfix for drawing single axis.
  * Bugfix for missing options parsing for some of MGL commands.
  * Bugfix for .pmin suffix in MGL. Add mglData::MaximalNeg() and
    mglData::MinimalPos() functions. Add .nmin and .nmax suffixes.
  * Bugfix for colorbar labels.
  * Force using python 2.7 by default.
  * Minor bugfixes and memory leaks.
- Disable Octave interface due to Octave 3.8.0 changes
- Disable openmp support due to instability
* Mon Nov 11 2013 dmitry_r@opensuse.org
- Update to version 2.2
  * Add OpenMP calls mostly everywhere (can work as replacement
    of pthreads - a bit faster since more loops is parallelized).
  * Greatly speed up consequent FFT and Hankel transforms. Add
    mgl_clear_fft() function for manual clearing of saved FFT/Hankel data.
  * Add OHLC() plot for drawing Open-High-Low-Close diagram
  * Add wxMathGL widget.
  * Add interface for Lua v.5.1.
  * Add mask for face drawing if one of symbols "-+=;oOsS~<>jdD*^"
    is specified in color scheme. This work only for export in
    bitmap images.
  * Add Quality=8 for dots drawing (extremely fast).
  * Add styles '4','6','8' for Cone() and Cones() to produce square,
    hex-, octo-prism.
  * Add style 't' for Cones() to produce tubes (cylinders).
  * Add style '^' for Legend() to left/right align legend if its
    coordinates are right/left from the center
  * Add style '<', '^', '>' for aligning/centering boxes in Bars(),
    Barh(), BoxPlot(), Cones(). Also this plots become centered by
    default if nx sizes are the same for all data.
  * Add Dots() function which set independently both color and alpha
    of dots
  * Improve automatic axis position. Add style '^' for inverse
    automatic axis position.
  * Improve tick labeling. Add style TuneTicks&4 for zero filling
    of tick labels.
  * Add mglData::Refill() for filling by interpolation of
    parametrically dependent data
  * Add transparency for Area() and Region() plots.
  * Add mgl_clf_chr() function and extend 'clf' command.
  * Fourier now perform true inverse Fourier transform (instead of
    backward one).
  * Improve/change lighting from local sources. Add SetDiffuse() function.
  * C functions now return NULL if HMDT data cannot be created for
    given input argument(s).
  * Enable line width for Mesh() and Fall() plots.
  * Replace +INF and -INF by NAN in textual formula output.
  * Add manual compression of JSON.
  * Define WORDS_BIGENDIAN and HAVE_MEMRCHR (thanks to Dinar Valeev).
  * Bugfix for cleaning unused points.
  * Fix 'setsize' command at UDAV starting.
  * Rewrite MGL parsing by using std::wstring for avoiding possible
    bugs of wcs*() functions.
  * Minor bugfixes.
  * Update docs.
- Removed obsolete mathgl-bigendian.patch
- Removed obsolete mathgl-gsl-deprecated-code-usage.patch
* Tue Sep 17 2013 badshah400@gmail.com
- Add mathgl-gsl-deprecated-code-usage.patch to fix build failures
  with gsl version 1.16, notably in openSUSE:Factory.
* Sat Jun  1 2013 dmitry_r@opensuse.org
- Add package with static libraries
* Thu May 30 2013 dvaleev@suse.com
- Detect WORDS_BIGENDIAN and HAVE_MEMRCHR to build on bigendian
  platforms correctly (mathgl-bigendian.patch)
* Wed May  8 2013 dmitry_r@opensuse.org
- Update to version 2.1.3.1
  * bugfix release, see included ChangeLog.txt for details
* Thu May  2 2013 dmitry_r@opensuse.org
- Update to version 2.1.3
  * bugfix release, see included ChangeLog.txt for details
- Split libraries into separate packages
- Split mathgl CGI into separate package
- Spec file reformatting
- Removed obsolete mathgl-libpath.patch
* Thu Feb  7 2013 dmitry_r@opensuse.org
- Disable reading octave initialization files during build
* Mon Jan 28 2013 dmitry_r@opensuse.org
- Update to version 2.1.2
  * bugfix release, see included ChangeLog.txt for details
* Mon Dec 24 2012 dmitry_r@opensuse.org
- Update to version 2.1.1
  * bugfix release, see included ChangeLog.txt for details
  * removed obsolete mathgl-rpath.patch
  * updated mathgl-libpath.patch
* Wed Dec 19 2012 dmitry_r@opensuse.org
- Update rpath patch
  * mathgl-rpath.patch
* Wed Dec 19 2012 Rene.vanPaassen@gmail.com
- Add fltk-fluid for fedora
- Recommends tag conditional on suse versions
* Fri Dec 14 2012 dmitry_r@opensuse.org
- Update to version 2.1
  * see ChangeLog.txt for details
- Set correct path to documentation directory
  * udav-help-path.patch
- Disable rpath
  * mathgl-rpath.patch
- Update other patches
- Delete SLE-specific things from spec file
* Thu Nov 15 2012 Rene.vanPaassen@gmail.com
- Fix spec file for build on Fedora:
  * add dependencies (xmu, texi2html, texinfo-tex)
  * re-define _defaultdocdir, to reflect correct doc path
  * correct test for suse_version
* Wed Oct 17 2012 dmitry_r@opensuse.org
- Locate documentation to right place
  * mathgl-doc-path.patch
- Update post and postup for octave-mathgl
* Fri Aug 24 2012 dmitry_r@opensuse.org
- Fix octave-mathgl package installation
* Tue Aug 21 2012 dmitry_r@opensuse.org
- Add octave-mathgl package
- Add mathgl-examples package
* Sun Jul 29 2012 badshah400@gmail.com
- Update to version 2.0.3:
  + Make code compilable by compilers GNU/MinGW GCC, Clang, MS
    VisualStudio
  + Add mglTriangulation() using s_hull_pro algorithm
  + Add mglData::Grid() and mglGraph::DataGrid() for filling
    regular data by values of triangulated surface
  + Add cmake options ’enable-png’ and ’enable-zlib’
  + Add SetTimeUTC() for using UTC time instead of local one
  + Add SetTickShift() for additional shift of tick labels
  + Add mglGraph::MPI_Send() and mglGraph::MPI_Recv()
  + Vector plots now draw vector at edges, which are directed out
    of bounding box
  + Add gap between 1d plots for avoiding possible undetermined
    overlapping
  + Add parallel build for documentation
  + Bugfixes for memory leaks and uninitialized variables, for
    setting text size, for handling NAN color value, for missing
    lines in export to EPS/SVG
- Drop mathgl-cmake-enable-doc-option-fix.patch; implemented
  upstream
- Split udav into its own package
- Add %%suse_update_desktop_file for SLE to fix brp complaints
  about missing generic name for udav.desktop
- Add install-info post scriplets for the installed info files.
* Thu May 24 2012 badshah400@gmail.com
- Update to version 2.0.2:
  + Add 'U' style for Axis() which disable ticks rotation
  + Bugfix for enable-opengl option
  + Bugfix for lighting
- Changes from version 2.0.1:
  + Improve speed of drawing
  + Add reading 3d data files using mglData::ReadMat()
  + Exclude unnecessary dependencies/inclusions
  + Improve build system:
  - Add multithreading
  - Add install for Octave
  - Separate enable-doc option from enable-all
  + Minor bugfixes
- Add mathgl-cmake-enable-doc-option-fix.patch to fix the usage
  of the cmake option: enable-doc (sf#3529593)
- Modify existing patch mathgl-fix-python-module-path.patch
  to use DESTDIR environment variable instead of RPM_BUILD_ROOT
  directly; set DESTDIR during make install stage
- Enable building with hdf5 support: introduces build dependency
  on hdf5-devel
- Disable octave bindings for now as they do not build
- Enable building on SLE 11 by turnning off doc building for it.
* Wed May  9 2012 badshah400@gmail.com
- Add mathgl-fix-python-module-path.patch to fix the path where
  python modules are installed.
* Sat May  5 2012 badshah400@gmail.com
- Update to version 2.0:
  + mglGraph class is single plotter class instead of mglGraphZB,
    mglGraphPS and so on
  + Text style and text color positions are swapped. I.e. text
    style ‘r:C’ give red centered text, but not roman dark cyan
    text as for v.1.*
  + ColumnPlot() indexing is reverted
  + Move most of arguments of plotting functions into the string
    parameter and/or options
  + "Bright" colors (like {b8}) can be used in color schemes and
    line styles
  + Intensively use pthread internally for parallelization of
    drawing and data processing
  + Add tick labels rotation and skipping. Add ticks in
    time/date format
  + New kinds of plots (Tape(), Label(), Cones(), ContV())
  + Extend existing plots
  + New primitives (Circle(), Ellipse(), Rhomb(), ...)
  + New plot positioning (MultiPlot(), GridPlot())
  + Improve MGL scripts. Add ’ask’ command and allow string
    concatenation from different lines
  + Export to LaTeX and to 3D formats (OBJ, OFF, STL)
  + Add pipes support in utilities (mglconv, mglview)
- Turn off fltk bindings for openSUSE 12.1 and lower as they
  cause build errors
- Disable python-mathgl package as it does not build
- Rebase mathgl-fltk.patch
- Add mathgl-libpath.patch to allow setting the location of
  installed libraries using a cmake variable
- Add texlive-latex as build dependency; required for
  generation of pdf documentation.
  - -----------------------------------------------------------------
* Sat Feb 25 2012 scorot@free.fr
- fix build for SLE-11
* Sat Feb 25 2012 scorot@free.fr
- fix build for SLE-11
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Mon Oct  3 2011 dimstar@opensuse.org
- Fix typo in patch tagline.
* Sat Aug 20 2011 badshah400@gmail.com
- Miscellaneous spec file corrections
* Tue Aug 16 2011 badshah400@gmail.com
- Fix build issues with openSUSE < 11.4
* Tue Aug 16 2011 badshah400@gmail.com
- Initial package (version 1.11.2)
